from distutils.core import setup

setup(
    name='django_mock_queries',
    packages=['django_mock_queries'],
    version='0.0.9',
    description='A django library for mocking queryset functions in memory for testing',
    author='Phivos Stylianides',
    author_email='stphivos@gmail.com',
    url='https://github.com/stphivos/django-mock-queries',
    keywords=['django', 'mocking', 'tdd'],
    classifiers=[],
)
